import { DynamoDB, S3 } from 'aws-sdk';
import { withCors } from '../../utils/addingCors';

const dynamoDb = new DynamoDB.DocumentClient();
const s3 = new S3();
const tableName = process.env.TABLE_NAME;
const bucketName = process.env.BUCKET_NAME;

export const handler = async (event: any) => {
  const contactId = event.pathParameters?.contactId;

  if (!contactId) {
    return withCors(400, { error: 'Missing required contact ID' });
  }

  try {
    // Fetch the contact to get the image URL
    const result = await dynamoDb
      .get({
        TableName: tableName!,
        Key: { id: contactId },
      })
      .promise();

    const contact = result.Item;

    if (!contact) {
      return withCors(404, { error: 'Contact not found' });
    }

    // Extract the S3 key from the image URL
    const imageUrl = contact.imageUrl;
    const url = new URL(imageUrl);
    const imageKey = url.pathname.substring(1);

    // Delete the contact's image from S3 (if it exists)
    if (imageKey) {
      await s3
        .deleteObject({
          Bucket: bucketName!,
          Key: imageKey,
        })
        .promise();
    }

    // Delete the contact from DynamoDB
    await dynamoDb
      .delete({
        TableName: tableName!,
        Key: { id: contactId },
      })
      .promise();

    return withCors(200, { message: 'Contact deleted successfully' });
  } catch (error) {
    console.error(error);
    return withCors(500, { error: 'Could not delete contact' });
  }
};
