import {
  InitiateAuthCommand,
  InitiateAuthCommandInput,
} from '@aws-sdk/client-cognito-identity-provider';
import { cognitoClient } from './awsCognito';
import { poolData } from '../constants';

export const login = async (email: string, password: string) => {
  const params: InitiateAuthCommandInput = {
    AuthFlow: 'USER_PASSWORD_AUTH',
    ClientId: poolData.ClientId,
    AuthParameters: {
      USERNAME: email,
      PASSWORD: password,
    },
  };

  const command = new InitiateAuthCommand(params);

  try {
    const response = await cognitoClient.send(command);
    if (response.AuthenticationResult?.AccessToken) {
      console.log('Login success:', response.AuthenticationResult.AccessToken);

      const tokens = {
        idToken: response.AuthenticationResult.IdToken,
        accessToken: response.AuthenticationResult.AccessToken,
      };

      return tokens;
    } else {
      throw new Error('Authentication failed.');
    }
  } catch (error) {
    console.error('Login failed:', error);
    throw error;
  }
};
