import Button from '@mui/material/Button';
import Stack from '@mui/material/Stack';
import TextField from '@mui/material/TextField';
import Typography from '@mui/material/Typography';
import Logo from 'components/Logo';
import useResponsive from 'hooks/useResponsive';
import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { login } from '../../authServices/login';
import { loginSlice } from 'storeSlices/authSlice';
import { useAppDispatch } from 'hooks/storeHooks';

export default function LoginPage() {
  const navigate = useNavigate();
  const dispatch = useAppDispatch();
  const isMobile = useResponsive('down', 'sm');

  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');

  const handleLogin = async () => {
    try {
      const tokens = await login(email, password);
      dispatch(loginSlice({ tokens: tokens, user: { email } }));
    } catch (error) {
      setError(`Login failed: ${error}`);
    }
  };

  const handleSignUp = () => {
    navigate('/auth/signup');
  };

  return (
    <Stack
      sx={{ height: isMobile ? 'auto' : '100%', pt: isMobile ? 10 : 0 }}
      justifyContent='center'
      alignItems='center'
      maxWidth={500}
      mx='auto'
      gap={2}
    >
      <Stack alignItems='center'>
        <Logo sx={{ width: 100, height: 100 }} />
        <Typography variant='h1'>Contacts App</Typography>
      </Stack>
      <TextField
        label='Email'
        variant='outlined'
        value={email}
        onChange={(e) => setEmail(e.target.value)}
        fullWidth
      />
      <TextField
        label='Password'
        type='password'
        variant='outlined'
        value={password}
        onChange={(e) => setPassword(e.target.value)}
        fullWidth
      />
      <Button variant='contained' color='primary' onClick={handleLogin}>
        Login
      </Button>
      <Button variant='contained' color='primary' onClick={handleSignUp}>
        SignUp Page
      </Button>
      {error && <Typography color='error'>{error}</Typography>}
    </Stack>
  );
}
