import { useNavigate, useParams } from 'react-router-dom';

import Page from 'components/Page';
import ContactForm from './ContactForm';

import {
  useGetContactByIdQuery,
  useUpdateContactMutation,
} from 'storeSlices/apiSlice';
import { skipToken } from '@reduxjs/toolkit/query';
import { SingeContactFormValues } from 'types';
import { CONTACTS_ROUTES } from 'routes/paths';
import { useState } from 'react';

export default function EditContact() {
  const { id } = useParams();
  const navigate = useNavigate();
  const [isImageChanged, setIsImageChanged] = useState(false);

  const [
    updateContact,
    { data: editContactData, isLoading: EditIsLoading, isError },
  ] = useUpdateContactMutation();

  const { data, isLoading } = useGetContactByIdQuery(id ?? skipToken);

  if (isLoading) {
    return <>Loading</>;
  }

  if (!data) {
    return <>No Data</>;
  }

  const handleEdit = async (value: SingeContactFormValues) => {
    await updateContact({
      id: id,
      ...value,
      image: isImageChanged ? value.image : data.image,
    });

    navigate(CONTACTS_ROUTES.list);
  };

  const handleCancel = () => {
    navigate(CONTACTS_ROUTES.list);
  };

  const handleImageChange = () => {
    setIsImageChanged(true);
  };

  return (
    <Page title='Edit contact'>
      <ContactForm
        title='Edit contact'
        buttonName='Edit'
        onCancel={handleCancel}
        onSubmit={handleEdit}
        onImageChange={handleImageChange}
        value={{
          name: data.name,
          email: data.email,
          phone: data.phone,
          /*  labels: data?.labels,  */
          image: data?.imageUrl,
          isFavorite: data?.isFavorite,
        }}
      />
    </Page>
  );
}
